@@ -13,8 +13,6 @@ import tangelo
 from tangelo.minify_json import json_minify
 import tangelo.util
 
-cpserver = None
-
 
 class Tangelo(object):
     # An HTML parser for use in the error_page handler.
@@ -23,8 +21,7 @@ class Tangelo(object):
     # An in-band signal to treat HTML error messages as literal strings.
     literal = "literal:::"
 
-    def __init__(self, vtkweb=None, stream=None):
-        self.vtkweb = vtkweb
+    def __init__(self, stream=None):
         self.stream = stream
 
         # A dict containing information about imported modules.
@@ -37,45 +34,6 @@ class Tangelo(object):
         if self.stream:
             cherrypy.tree.mount(stream, "/stream")
 
-        # Mount a VTKWeb API if requested.
-        #
-        # TODO(choudhury): make the mounting directory configurable by the
-        # user.
-        if self.vtkweb is not None:
-            cherrypy.tree.mount(self.vtkweb, "/vtkweb")
-
-        # Mount Girder API if available.
-        try:
-            from girder.api import api_main
-
-            cherrypy.config.update({
-                "sessions": {"cookie_lifetime": 180},
-                "server": {"mode": "development"},
-                "database": {
-                    "host": "localhost",
-                    "port": 27017,
-                    "user": "",
-                    "password": "",
-                    "database": "girder"
-                }
-            })
-
-            class Dummy(object):
-                pass
-
-            cherrypy.tree.mount(api_main.addApiToNode(Dummy()), "/girder", {
-                '/': {
-                    'request.dispatch': cherrypy.dispatch.MethodDispatcher()
-                }
-            })
-        except ImportError:
-            # Ok, just don't mount it.
-            pass
-
-    def cleanup(self):
-        if self.vtkweb:
-            self.vtkweb.shutdown_all()
-
     @staticmethod
     def error_page(status, message, traceback, version):
         if message.startswith(Tangelo.literal):
@@ -266,7 +224,7 @@ class Tangelo(object):
             reqpath = reqpath[:-1]
         files = filter(lambda x: len(x) > 0 and x[0] != ".",
                        os.listdir(dirpath))
-        #filespec = ["Type", "Name", "Last modified", "Size"]
+        # filespec = ["Type", "Name", "Last modified", "Size"]
         filespec = []
         for f in files:
             p = dirpath + os.path.sep + f
