@@ -2,5 +2,7 @@
 # exception, is meant for testing the error handling of Tangelo's web service
 # module loader system.
 
+
 def run():
-    raise RuntimeError("this is an example error, from web service 'exceptional'")
+    raise RuntimeError("this is an example error, " +
+                       "from web service 'exceptional'")
